from skbuild import setup 

setup(
    name="TheengsDecoder",
    version="0.1.0",
    description="A message decoder for the Internet of Things",
    author='Theengs',
    license=" GPL-3.0 License",
    packages=['TheengsDecoder'],
)

